@@ -396,203 +396,63 @@ def color_demo():
     from XEdu.hub import Workflow as wf
     color = wf(task='gen_color',download_path='new_download')# ,checkpoint='/home/user/下载/colorization-master/colorizer_siggraph17.onnx')
     img = cv2.imread('/home/user/下载/colorization-master/imgs/ansel_adams3.jpg')
-    result = color.inference(data='/home/user/下载/colorization-master/imgs/ansel_adams3.jpg',img_type='pil',show=True)
-    color.show(result)
+    result,xxx = color.inference(data='/home/user/下载/colorization-master/imgs/ansel_adams3.jpg',img_type='cv2',show=True)
+    # color.show(xxx)
     color.format_output(lang="zh")
-    color.save(result,"color_ou.jpg")
-
-
-def kimi_stream_demo():
-    import os
-    from openai import OpenAI
-    
-    client = OpenAI(
-        api_key="sk-c1nBfFK5mcwtilUBr6uvAVulwUhIBWNOqrbVZstvmwBXUcI9",
-        base_url="https://api.moonshot.cn/v1",
-    )
-    
-    response = client.chat.completions.create(
-        model="moonshot-v1-8k",
-        messages=[
-            {
-                "role": "system",
-                "content": "你是 Kimi，由 Moonshot AI 提供的人工智能助手，你更擅长中文和英文的对话。你会为用户提供安全，有帮助，准确的回答。同时，你会拒绝一切涉及恐怖主义，种族歧视，黄色暴力等问题的回答。Moonshot AI 为专有名词，不可翻译成其他语言。",
-            },
-            {"role": "user", "content": "你好，我叫李雷，1+1等于多少？"},
-        ],
-        temperature=0.3,
-        stream=True,
-    )
-    
-    collected_messages = []
-    for idx, chunk in enumerate(response):
-        # print("Chunk received, value: ", chunk)
-        chunk_message = chunk.choices[0].delta
-        if not chunk_message.content:
-            continue
-        collected_messages.append(chunk_message)  # save the message
-        print(f"#{idx}: {''.join([m.content for m in collected_messages])}")
-    print(f"Full conversation received: {''.join([m.content for m in collected_messages])}")
-
-def  llm_stream():
-    import json
-    import requests
-
-    url = "https://api.moonshot.cn/v1"  # 替换为目标URL
-    data = {
-        "stream": True,
-        "model": "moonshot-v1-8k",
-        "messages": [
-            {
-                "role": "user",
-                "content": "你是谁"
-            },
-        ]
-    }
-    headers = {
-        "Authorization": "Bearer sk-c1nBfFK5mcwtilUBr6uvAVulwUhIBWNOqrbVZstvmwBXUcI9",
-    }
-
-    # 使用 with 语句确保请求完成后释放资源
-    with requests.post(url, json=data, headers=headers, timeout=60000, stream=True) as response:
-        # print(response.headers)
-        for chunk in response.iter_lines(chunk_size=None):
-            mChunk = chunk.decode('utf-8')
-            if "[DONE]" in mChunk:
-                break
-            print(mChunk)
-            lines = mChunk.splitlines()
-            for line in lines:
-                respStr = line.strip().replace("data: ", "")
-                respContent = ""
-                try:
-                    respJson = json.loads(respStr)
-                    respContent = respJson["choices"][0]["delta"]["content"]
-                except  Exception as e:
-                    respContent = ""
-                print(respContent)
-
-# 存储各种服务的API Key和URL
-class ServiceProvider:
-    BASE_URL = {
-        "openrouter":"https://openrouter.ai/api/v1/chat/completions",
-        "moonshot":"https://api.moonshot.cn/v1/chat/completions",
-        "google": "https://generativelanguage.googleapis.com/v1beta/models/gemini-pro:generateContent?key=AIzaSyBY-2VWbVvWybt8qjnruUY4tip4X_OwCp8"
-
-    }
-    API_KEY = {
-        "openrouter": "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",
-        "moonshot": "sk-c1nBfFK5mcwtilUBr6uvAVulwUhIBWNOqrbVZstvmwBXUcI9",
-        "google": "AIzaSyBY-2VWbVvWybt8qjnruUY4tip4X_OwCp8"
-    }
-    MODEL = {
-        "openrouter": "mistralai/mistral-7b-instruct:free",
-        "moonshot": "moonshot-v1-8k",
-        "google": "gemini-pro"
-    }
-    def __init__(self, service_name):
-        self.api_key = ServiceProvider.API_KEY[service_name]
-        self.url = ServiceProvider.BASE_URL[service_name]
-        self.model = ServiceProvider.MODEL[service_name]
-import requests
-import json
-class Client:
-    """docstring for Client
-    
-    """
-
-    def __init__(self, provider=None,base_url=None,api_key=None,model=None):
-        self.provider = provider
-        self.base_url = base_url
-        self.api_key = api_key
-        self.model = model
-
-        if provider:
-            self.api_key = ServiceProvider.API_KEY[provider]
-            self.url = ServiceProvider.BASE_URL[provider]
-            self.model = ServiceProvider.MODEL[provider]
-    
-    def inference(self, message, stream=False):
-        if isinstance(message,str):
-            messages = [{"role": "user", "content": message}]
-        else:
-            messages = message
-        if stream:
-            data = json.dumps({
-                        "model": self.model, # Optional
-                        "messages": messages,
-                        "stream": stream,
-                    })
-        else:
-            data = json.dumps({
-                        "model": self.model, # Optional
-                        "messages": messages,
-                    })
-        response = requests.post(
-            url=self.url,
-            headers={
-                'Accept': 'text/event-stream',
-                "Authorization": f"Bearer {self.api_key}",
-                "Content-Type": "application/json",
-            },
-            data=data
-            # stream=stream,
-        )
-        if stream:
-            content = ''
-            for output in response.iter_lines(chunk_size=None):
-                # print("+++++++++++",output)
-                if output==b'data: [DONE]':
-                    break
-                # 判断content是否为空
-                elif output[:6] == b'data: ':
-                    # print("------------",output[6:])
-                    data = output[6:]
-                    output = json.loads(data)
-                    content = output["choices"][0]["delta"]["content"]# .encode('latin1').decode('utf-8')
-        else:
-            try:
-                content = response.json()["choices"][0]["message"]
-            except Exception as e:
-                content = response.json()
-
-        print(content)
-        return content
+    color.save(xxx,"color_ou.jpg")
 
 def llm_demo(stream=False):
     from XEdu.LLM import Client
     print(Client.support_provider())
-    # client = Client(provider="openrouter",api_key="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")
-    client = Client(base_url="https://openrouter.ai/api/v1",api_key="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",model="mistralai/mistral-7b-instruct:free")
-    # client = Client(provider="moonshot",api_key="sk-c1nBfFK5mcwtilUBr6uvAVulwUhIBWNOqrbVZstvmwBXUcI9")
-    # client = Client(provider="deepseek",api_key="sk-bc3da8219e624f52a80b565a6aa31dcd")
-    # client = Client(provider="glm",api_key="03a6c63bc0d356c5819f20b009b511e9.EMc2bCVDb7XJYuJf")
-    # client = Client(provider="replicate",api_key="r8_HjFF0greljF48VQUFpCOUF021NSciu62QhRZP") # todo
-    # print(client.support_model())
-    # detail = client.model_info("deepseek-chat")
+    print(Client.support_provider('zh'))
+    client = Client(provider="openrouter",api_key="xxx")
+    print(client.support_model())
     # print(detail)
-    res = client.inference("你好,用中文介绍一下你自己",stream=True)
+    # res = client.inference("你好,用中文介绍一下你自己,20字以内",stream=True)
+    # for i in res:
+    #     print(i, flush=True, end='')
+    print("\n ------------非流式-------------\n")
+    res = client.inference("你好,用中文介绍一下你自己,20字以内")
+    print(res)
+    # client.run()
 
 def seg_demo():
     from XEdu.hub import Workflow as wf
-    seg = wf(task='seg_sam') # iris act 
-    img_p = '/home/user/下载/sam/efficientvit/assets/fig/cat.jpg'
+    seg = wf(task='segment_anything') # iris act 
+    img_p = 'car_plate.jpg'
     # img = 'ele.jpg'
     # img = 'fire.jpg'
-    result, img = seg.inference(data=img_p,img_type='cv2',show=True,prompt=[[170,70],[380,270]])
-    result, img = seg.inference(data=img_p,img_type='cv2',show=True,prompt=[[380,270]])
-    seg.show(img)
+    # result, img = seg.inference(data=img_p,img_type='cv2',show=True,prompt=[[170,70],[380,270]])
+    # result, img = seg.inference(data=img_p,img_type='cv2',show=True,prompt=[380,270])
+    result, img = seg.inference(data=img_p,img_type='cv2',show=True)
+    # seg.show(img)
     import time
-    start = time.time()
-    result,img = seg.inference(data=img_p,mode='box',prompt=[170,70,380,270],img_type='cv2',show=True)
-    result,img = seg.inference(data=img_p,mode='box',prompt=[[170,70,380,270]],img_type='cv2',show=True)
-    result,img = seg.inference(data=img_p,mode='box',prompt=[[170,70,380,270]],img_type='cv2',show=True)
-    print(time.time()-start)
+    # start = time.time()
+    # result,img = seg.inference(data=img_p,mode='box',img_type='cv2',show=True)
+    result,img = seg.inference(data=img_p,mode='box',prompt=[[170,70,380,270]],img_type='pil',show=True)
+    # result,img = seg.inference(data=img_p,mode='box',prompt=[[170,70,380,270]],img_type='cv2',show=True)
+    # print(time.time()-start)
     # print(result.shape)
-    seg.show(result[0])
-    seg.show(img)
-    seg.format_output(lang="zh")
-    seg.save(img,"seg_ou.png")
+    # seg.show(result[0])
+    # seg.show(img)
+    # seg.format_output(lang="zh")
+    seg.save(img,"seg_ou.bmp")
+
+def mde_demo():
+    from XEdu.hub import Workflow as wf
+    mde = wf(task='depth_anything')
+    import time
+    a = time.time()
+    res = mde.inference(data="det.jpg")
+    print(time.time()-a)
+    mde.show(res)
+    res, img = mde.inference(data="ele.jpg",img_type='cv2',show=True)
+    mde.show(img)
+    mde.show(res)
+    # mde.show(img)
+    mde.save(img,"mde_ou1.jpg")
+    mde.save(res,"mde_ou2.jpg")
+    mde.format_output(lang="zh")
 
 if __name__ == "__main__":
     # pose_infer_demo()
@@ -614,9 +474,18 @@ if __name__ == "__main__":
     # embedding_demo()
     # color_demo()
     # llm_demo()
-    # client = Client(provider="openrouter")
-    # client.inference("你好,用中文介绍一下你自己")
-    # llm_stream()
-    seg_demo()
-
+    # seg_demo()
+    mde_demo()
 
+    # from openai import OpenAI 
+	 
+    # client = OpenAI(
+	#     api_key="09dbc4728a253c77cda022286e45435e.2cywtCQJfmWM8TJX",
+	#     base_url="https://open.bigmodel.cn/api/paas/v4/"
+	# ) 
+    # print(client.models.list())
+    # import requests
+    # url = 'https://download.openxlab.org.cn/repos/file/xedu/hub-model/main?filepath=depth_anything.onnx&sign=3f1bb6d4e6a3807af6d83d2cf110ed2f&nonce=1719300806979'
+    # url = 'https://download.openxlab.org.cn/repos/file/xedu/hub-model/main?filepath=depth_anything.onnx&sign=6f14e5a72db915ac7a767a124c76242a&nonce=1719306041356'
+    # res_length = requests.get(url, stream=True)
+    # print(res_length.headers['Content-Length'])
