@@ -76,7 +76,8 @@ task_dict = {
         "embedding_image":"embedding_image.onnx",
         "embedding_text":"embedding_text.onnx",
         "gen_color":"gen_color.onnx",
-        "seg_sam":['seg_sam_encoder.onnx','seg_sam_decoder.onnx'],
+        "segment_anything":['seg_sam_encoder.onnx','seg_sam_decoder.onnx'],
+        "depth_anything":"depth_anything.onnx",
         "det_face":"...",
         "ocr":"...",
         "mmedu":"...",
@@ -137,11 +138,14 @@ class Workflow:
             - det_face：人脸检测
             - cls_imagenet：图像分类，1000类，基于ImageNet数据集
             - gen_style：风格迁移，5种风格
+            - gen_color：图像着色
             - nlp_qa：问答系统，基于SQuAD数据集
             - drive_perception：全景驾驶感知系统，包括交通对象检测、可行驶道路区域分割和车道检测任务
             - embedding_image：CLIP图像嵌入
             - embedding_text：CLIP文本嵌入   
             - ocr：光学字符识别，基于rapidocr
+            - segment_anything：图像分割，基于Segment Anything Model (SAM)
+            - depth_anything：深度估计
             - mmedu：MMEdu模型推理
             - basenn：BaseNN模型推理
             - baseml：BaseML模型推理
@@ -152,7 +156,7 @@ class Workflow:
             checkpoint：模型权重文件的路径。
             download_path：模型文件即将下载到的路径。
 
-        更多用法及算法详解请参考：https://xedu.readthedocs.io/zh/master/xedu_hub/introduction.html    
+        更多用法及算法详解请参考：https://xedu.readthedocs.io/zh-cn/master/xedu_hub/introduction.html
     """
     @classmethod
     def support_task(cls):
@@ -219,7 +223,7 @@ class Workflow:
             self.questions = []
             self.contexts = []
             self.doc = None
-        default_task = ['det_body','det_body_l','det_coco','det_coco_l','pose_body17','pose_body17_l','pose_body26','pose_wholebody133','pose_face106','pose_hand21','det_hand','cls_imagenet','gen_style','nlp_qa','drive_perception','embedding_image','embedding_text','gen_color']
+        default_task = ['depth_anything','det_body','det_body_l','det_coco','det_coco_l','pose_body17','pose_body17_l','pose_body26','pose_wholebody133','pose_face106','pose_hand21','det_hand','cls_imagenet','gen_style','nlp_qa','drive_perception','embedding_image','embedding_text','gen_color']
         
         if checkpoint is None and self.task in default_task: # 若不指定权重文件，则使用对应任务的默认模型
             if self.task == 'gen_style':
@@ -269,6 +273,7 @@ class Workflow:
                 }
                 model_name_map_download = {
                     "gen_color":"https://download.openxlab.org.cn/repos/file/xedu/hub-model/main?filepath=gen_color.onnx&sign=2838feb49073bb8f756d57a9f78a68ab&nonce=1713425582020",
+                    "depth_anything":'https://download.openxlab.org.cn/repos/file/xedu/hub-model/main?filepath=depth_anything.onnx&sign=6f14e5a72db915ac7a767a124c76242a&nonce=1719306041356',
                 }
                 if self.task in model_name_map_download.keys():
                     downloader = Downloader(model_name_map_download[self.task], os.path.join(path, self.task_dict[self.task]),output_dir=path)
@@ -317,13 +322,16 @@ class Workflow:
                     pass
             else:
                 self.model = model
-        elif  self.task == 'seg_sam':
-            checkpoint = [os.path.join(path, task_dict[self.task][0]),os.path.join(path, task_dict[self.task][1])]
+        elif  self.task == 'segment_anything':
+            if checkpoint is None:
+                checkpoint = [os.path.join(path, task_dict[self.task][0]),os.path.join(path, task_dict[self.task][1])]
+            else:
+                assert isinstance(checkpoint,list) and len(checkpoint)==2, "checkpoint should be a list of two paths for encoder and decoder."
             if not os.path.exists(checkpoint[0]):
                 print("本地未检测到{}任务对应encoder模型，云端下载中...".format(self.task))
                 if not os.path.exists(path):
                     os.mkdir(path)
-                downloader = Downloader("https://download.openxlab.org.cn/repos/file/xedu/hub-model/main?filepath=seg_sam_encoder.onnx&sign=e56fc1c91d73d75d42c32b95a34ac42b&nonce=1717570798621", checkpoint[0],output_dir=path)
+                downloader = Downloader("https://download.openxlab.org.cn/repos/file/xedu/hub-model/main?filepath=seg_sam_encoder.onnx&sign=54ce80fbe91914e7f058fe83e35962d1&nonce=1718180611636", checkpoint[0],output_dir=path)
                 downloader.start()
             if not os.path.exists(checkpoint[1]):
                 print("本地未检测到{}任务对应decoder模型，云端下载中...".format(self.task))
@@ -409,8 +417,28 @@ class Workflow:
             return self._embedding_text_infer(data)
         elif self.task in ['gen_color']:
             return self._gen_color_infer(data,show,img_type)
-        elif self.task in ['seg_sam']:
+        elif self.task in ['segment_anything']:
             return self._seg_sam_infer(data,show,img_type,**kwargs)
+        elif self.task in ['depth_anything']:
+            return self._mde_da_infer(data,show,img_type)
+        
+    def _mde_da_infer(self,data,show,img_type):
+        self._get_img = 'cv2'
+        if isinstance(data,str):
+            assert os.path.exists(data),ecf.NO_SUCH_FILE(data)
+            np_data = cv2.imread(data)
+        else:
+            np_data = data
+
+        from .models.depth_anything import da_onnx_infer
+        self.depth_res = da_onnx_infer(np_data,self.model)
+        if show:
+            self.show(self.depth_res)
+        if img_type:
+            return self.depth_res,self.depth_res
+        return self.depth_res
+
+                
 
     def _seg_sam_infer(self,data,show,img_type,mode='point',prompt=None):
         if isinstance(data,str):
@@ -426,8 +454,12 @@ class Workflow:
         img_embeddings = self.model[0](img) # encoder
         if mode == "point":
             if prompt is None:
-                prompt = np.array([origin_image_size[1] /2,origin_image_size[0]/2,1],dtype='float32')
-            # point = np.concatenate([prompt, [1]],dtype='float32')[None,None,:]
+                prompt = np.array([[origin_image_size[1] /2,origin_image_size[0]/2]],dtype='float32')
+            else:
+                if len(np.array(prompt).shape) == 1:
+                    prompt = np.array(prompt)[None,:]
+                else:
+                    prompt = np.array(prompt)
             ax = [[1] for i in range(len(prompt))]
             point = np.concatenate([prompt, ax],axis=1)
             point = np.array([point],dtype='float32')
@@ -441,10 +473,13 @@ class Workflow:
             ) # decoder
             self.masks = masks[0]
         elif mode == "box":
-            if len(np.array(prompt).shape) == 1:
-                boxes = np.array(prompt)[None,:]
+            if prompt is None:
+                boxes = np.array([[0,0,origin_image_size[1],origin_image_size[0]]],dtype='float32')
             else:
-                boxes = np.array(prompt)
+                if len(np.array(prompt).shape) == 1:
+                    boxes = np.array(prompt)[None,:]
+                else:
+                    boxes = np.array(prompt)
             masks, self.mask_scores, _ = self.model[1].run(
                 img_embeddings=img_embeddings,
                 origin_image_size=origin_image_size,
@@ -987,9 +1022,7 @@ class Workflow:
             # data  = data.astype(np.float32) # tab iris
         ort_inputs = {'input': data}
         self.basenn_res = ort_session.run(['output'], ort_inputs)
-            # 索引映射回词表
-            # idx = res[0].argmax()
-            # print(ix2word[idx])
+
         if img_type is not None:
             dummy_path = os.path.join(os.path.abspath(os.path.dirname(__file__)),'none.jpg')
             img = cv2.imread(dummy_path)
@@ -1050,7 +1083,6 @@ class Workflow:
             image = cv2.imread(data)
         else:
             image = copy.copy(data)
-        ### 推理
         face_model = self.model
    
         scaleFactor = 1.1 if 'scaleFactor' not in kwargs else  float(kwargs['scaleFactor'])   
@@ -1302,6 +1334,8 @@ class Workflow:
             # img = cv2.cvtColor(img, cv2.COLOR_BGR2RGB)
             if isinstance(img,tuple):
                 img = img[1]
+            if img.dtype != 'uint8':
+                img = (img*255).astype('uint8')
             cv2.imwrite(save_path,img)
         elif self._get_img.lower() == 'pil':
             if isinstance(img,tuple):
@@ -1310,6 +1344,9 @@ class Workflow:
             if img.dtype != 'uint8':
                 img = (img*255).astype('uint8')
             a = Image.fromarray(img)
+            # 如果savepath以jpg结尾，则将rgbaa准华为rgb
+            if save_path.split('.')[-1].lower() in ['jpg','jpeg']:
+                a = a.convert('RGB')
             a.save(save_path)
             # plt.imshow(img)
             # plt.axis('off')
@@ -1428,6 +1465,8 @@ class Workflow:
             formalize_result = self.style_res
         elif self.task in ['gen_color']:
             formalize_result = self.color_res
+        elif self.task in ['depth_anything']:
+            formalize_result = self.depth_res
         elif self.task in ['nlp_qa']:
             formalize_keys = {
                 "zh":["问题","回答","文本","分数","上下文"],
@@ -1466,7 +1505,7 @@ class Workflow:
                 formalize_keys[language][2]:self.lane_mask,
                 formalize_keys[language][3]:self.area_mask,
             }
-        elif self.task in ['seg_sam']:
+        elif self.task in ['segment_anything']:
             formalize_keys = {
                 "zh":["掩码","分数"],
                 "en":["masks","scores"],
